crypto = require( "crypto" )
defaults = require( "./defaultKeys" )

function Keygrip( keys ) {
  if ( !( this instanceof Keygrip ) ) return new Keygrip( keys )
  
  if ( !keys || !( 0 in keys ) ) {
    console.warn( "No keys specified, using defaults instead." )
    keys = defaults
  }
  
  function sign( data, key ) {
    return crypto
      .createHmac( "sha1", key )
      .update( data ).digest( "base64" )
      .replace( /\/|\+|=/g, function( x ) {
        return ({ "/": "_", "+": "-", "=": "" })[ x ]  
      })
  }

  this.sign = function( data ){ return sign( data, keys[ 0 ] ) }

  this.verify = function( data, digest ) {
    for ( var i = 0, l = keys.length; i < l; i++ ) {
      if ( digest === sign( data, keys[ i ] ) ) return i
    }
    
    return -1
  }
}

Keygrip.sign = Keygrip.verify = function() {
  throw "Usage: require( 'keygrip' )( <array-of-keys> )"
}

module.exports = Keygrip